@@ -10,13 +10,6 @@ class TestGI(unittest.TestCase):
         '''GLib enum'''
         self.assertEqual(GLib.IOCondition.IN.value_nicks, ['in'])
 
-    def test_glib_flag(self):
-        '''GLib flag'''
-        nicks = set(GLib.IOFlags.IS_READABLE.value_nicks)
-        # https://gitlab.gnome.org/GNOME/pygobject/-/issues/542
-        nicks.discard('none')
-        self.assertEqual(nicks, set(['is_readable']))
-
     def test_method(self):
         '''GLib method call'''
 
